Module trace_error::backtrace
[−]
[src]
Small extensions to the backtrace crate
This module defines a formatting API for formatting both inline and captured backtraces, and a structure for holding file and line level captured backtraces.
Structs
| DefaultBacktraceFmt |
Default backtrace formatter that tries to resemble rustc panic backtraces somewhat |
| SourceBacktrace |
Backtrace that also contains the exact line and file in which it originated from. |
Traits
| BacktraceFmt |
Trait to define formatting for backtrace symbols |
Functions
| format_trace |
Generates a formatted backtrace (via |