Struct trace_error::backtrace::SourceBacktrace
[−]
[src]
pub struct SourceBacktrace { /* fields omitted */ }Backtrace that also contains the exact line and file in which it originated from.
Usually created in a macro using the line!() and file!() macros
Methods
impl SourceBacktrace[src]
fn new(line: u32, file: &'static str) -> SourceBacktrace
Create a new SourceBacktrace if you know the file and file
fn raw(&self) -> &Backtrace
Get a reference to the raw Backtrace instance
fn line(&self) -> u32
Get the line at which this backtrace originated from
fn file(&self) -> &'static str
Get the file path (as a &'static str) in which this backtrace originated from
fn format<Fmt: BacktraceFmt>(&self, header: bool, reverse: bool) -> String
Format this backtrace with the given formatter and the given options